#
# spec file for package python-gspread
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-gspread
Version:        6.0.1
Release:        1.1
Summary:        Google Spreadsheets Python API
License:        MIT
URL:            https://github.com/burnash/gspread
Source:         https://github.com/burnash/gspread/archive/v%{version}.tar.gz
BuildRequires:  %{python_module betamax}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module google-auth-oauthlib >= 0.4.1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module xml}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-StrEnum >= 0.4.15
Requires:       python-google-auth >= 1.12.0
Requires:       python-google-auth-oauthlib >= 0.4.1
BuildArch:      noarch
%python_subpackages

%description
A Python module to access Google Spreadsheets.

Features
--------

* Google Sheets API v4.
* Open a spreadsheet by its *title*, *url* or *key*.
* Select cells by labels, e.g. 'A1'.
* Extract range, entire row or column values.
* Python 3 support.

%prep
%setup -q -n gspread-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# needs betamax-json-body-serializer that does not exist on pypi anywhere
#%%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} nosetests-%{$python_bin_suffix} -v

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/*

%changelog
* Wed Feb  7 2024 Dirk Müller <dmueller@suse.com>
- update to 6.0.1:
  * Allow client to use external Session object
  * Remove-py-3.7-support
  * bugfix/client export
  * Fix oauth flow typo
  * check oauth creds type using isinstance
  * Fix type hints at find method in worksheet.py
  * Fixup get empty cell value is None
  * Fix missing attribute spreadsheet in Worksheet.
  * update migration guide
* Tue Jan 30 2024 Dirk Müller <dmueller@suse.com>
- update to 6.0.0:
  * Remove deprecated method delete_row
  * Initial typing in client.py
  * Split client http client
  * Spelling fix & update docs with date_time_render_option
    behaviour
  * #966  Add sketch typing for utils.py
  * Remove accepted_kwargs decorator
  * Remplace named tuples with enums
  * Feature/add type hints worksheets
  * Implement hex color conversion
  * remove lastUpdateTime
  * Merge master into feature/release_6_0_0
  * Add type checking to lint
  * Warning/update swapped args
  * Improve Worksheet.sort() signature
  * Make get_values and alias of get
  * fix type issue (remove .first() function)
  * Remove/get records   use index
  * increase warning stacklevel from 1 to 2
  * Feature/merge master
  * feature/merge master
  * Simplify get records
  * Add util function to_records to build records
    in https://github.com/burnash/gspread/pull/1377
  * feature/add utils get records
  * Add migration guide for get_all_records
  * feature/merge master into release 6 0 0
  * Feature/release 6 0 0
* Sat Jan 13 2024 Dirk Müller <dmueller@suse.com>
- update to 5.12.4:
  * Fixed default value of merge_type parameter in merge_cells
    function docstring.
  * 1363 get all records retrieves a large number of empty rows
    after the end of the data
  * Many fixes for get_records
  * change worksheet.update migration guide
  * feature/readme migration v6
  * add deprecation warnings for lastUpdateTime...
  * remove use_index and references to it in get_records
  * make deprecation warning dependent on if kwarg is used for
    client_factory
  * fix 1352 expected headers broken
  * fix combine_merged_cells when using from a range that doesn't
    start at A1
  * feature -- adding worksheet.get_records to get specific row
    ranges
  * Fix list_spreadsheet_files return value
  * Fix warning message for worksheet.update method
  * change lambda function to dict (fix pyupgrade issue)
  * allows users to silence deprecation warnings
  * Add maintain_size to keep asked for size in get, get_values
  * Fix list_spreadsheet_files return value by @mephinet in
  * Fix merge_combined_cells in get_values (AND 5.11.2 RELEASE)
  * remove Drive API access on Spreadsheet init (FIX - VERSION
    5.11.1)
  * add docs/build to .gitignore
  * add release process to CONTRIBUTING.md
  * add test_fill_gaps and docstring for fill_gaps
  * Remove API calls from creationTime/lastUpdateTime
  * Fix Worksheet ID Type Inconsistencies
  * Add column_count prop as well as col_count
  * Add required kwargs with no default value
  * Add deprecation warnings for colors
  * Add better Exceptions on opening spreadsheets
  * Fix rows_auto_resize in worksheet.py by removing redundant
    self
  * Add deprecation warning for future release 6.0.x
  * FEATURE: show/hide gridlines (#1197)
  * CLEANUP: cleanup tox.ini, and ignore ./env
  * Refactor/update-contributing-guide
  * Spelling fix (with legacy option)
  * 457-fetch-without-hidden-worksheets
  * Add_deprecated_warning_sort_method
  * Update (and test for) internal properties on change
  * Feature: Add "Remove tab colour" method
  * Refresh-test-cassettes
  * update self._properties after batch_update
  * 700-fill-merged-cells
  * Fix/update-internal-properties
  * Add breaking change warning in Worksheet.update()
  * remove deprecated methods from tests
  * Bugfix/fix get last update time
  * Add batch notes insert/update/clear
  * #1104: added a delete by worksheet id method
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 5.7.2
  * Fix: hidden property might not be set from the API by @lavigne958 in #1151
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 5.7.1
  * Fix dependencies required version by @lavigne958 in #1147
- Update to version 5.7.0
  * chore: Update outdated LICENSE year by @bluzir in #1124
  * add dependabot to maintain dependencies by @lavigne958 in #1126
  * improve trigger on CI by @lavigne958 in #1134
  * Bump bandit from 1.7.0 to 1.7.4 by @dependabot in #1133
  * cancel previous run on same ref by @lavigne958 in #1135
  * Bump actions/setup-python from 2 to 4 by @dependabot in #1127
  * Bump actions/checkout from 2 to 3 by @dependabot in #1128
  * Bump black from 22.3.0 to 22.10.0 by @dependabot in #1132
  * Bump isort from 5.9.3 to 5.10.1 by @dependabot in #1131
  * Bump codespell from 2.1.0 to 2.2.2 by @dependabot in #1130
  * add named tuple for DateTimeRenderOption by @lavigne958 in #1136
  * Feature/copy cut paste by @lavigne958 in #1138
  * isSheetHidden method added to worksheet.py by @SazidAF in #1140
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 5.6.2 (2022-10-23)
  * update parent folder for client.copy method by @lavigne958 in #1123
- Update to version 5.6.0 (2022-09-10)
  * Fix clear_note method when using numeric boundaries by @lavigne958 in #1106
  * Fix a typo in the permissions:create API payload by @jiananma in #1107
  * Fix spreadsheet URL by @lavigne958 in #1110
  * Return created permission on Spreadsheet.share() by @lavigne958 in #1111
  * (fixed #1113) Supply correct Google API v3 permission for domains by @NickCrews in #1115
  * Bugfix/numericese all by @lavigne958 in #1119
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- 5.5.0 (2022-08-31)
  Use pathlib by @lavigne958 in #1057
  Migrate to drive API V3 by @lavigne958 in #1060
  Implement __eq__ method for Cell by @chisvi in #1063
  Add missing documentation on set_timeout by @lavigne958 in #1070
  Add method to transfer / accept ownership of a spreadsheet by @lavigne958 in #1068
  Add client_factory param to auth methods by @jlumbroso in #1075
  Fix list_protected_ranges by @lavigne958 in #1076
  Add function to convert column letter to column index by @lavigne958 in #1077
  Fix docstring name of named_range() param by @dgilman in #1081
  Fix grammar in docstring for client.export by @dgilman in #1080
  Many typo fixes to worksheet docstrings by @dgilman in #1083
  Fix function numericise_all by @lavigne958 in #1082
  Fix documentation about oauth_from_dict by @lavigne958 in #1088
  inherit_from_before option for insert_row/insert_rows by @yongrenjie in #1092
  add method to change the color of a tab by @lavigne958 in #1095
  docs: Fix a few typos by @timgates42 in #1094
  Fix typo in Worksheet.batch_format method by @lavigne958 in #1101
  [#]# New Contributors * @chisvi made their first contribution in #1063 * @jlumbroso made their first contribution in #1075 * @yongrenjie made their first contribution in #1092
- 5.4.0 (2022-06-01)
  fix typo by @joswlv in #1031
  Fix error message in get_all_records by @lavigne958 in #1028
  Added feature request #1022. Auto resizing is now available for rows … by @mketer1 in #1033
  add new method to hide/show a worksheet by @lavigne958 in #1030
  feat: Download PDF from Spreadsheet #1035 by @100paperkite in #1036
  Add test on auto_resize_columns by @lavigne958 in #1039
  Add method to unmerge cells by @lavigne958 in #1040
  Add method to delete a protected range by @lavigne958 in #1042
  Feature/clean organize documentation by @lavigne958 in #1043
  Add warning about deprecated oauth flow by @lavigne958 in #1047
  Add new batch_format method. by @lavigne958 in #1049
  Encode string to utf-8 when importing CSV content by @lavigne958 in #1054
  New Contributors
  @joswlv made their first contribution in #1031
  @mketer1 made their first contribution in #1033
  @100paperkite made their first contribution in #1036
- 5.3.2 (2022-04-12)
  Bugfix/black python3.10 by @lavigne958 in #1020
  Automate releases by @lavigne958 in #1025
  Bugfix/get all record duplicated columns by @lavigne958 in #1021
- 5.3.0 (2022-03-28)
  Feature/rework test cassettes recording by @lavigne958 in #1004
  add method list protected ranges by @lavigne958 in #1008
  Add new methods to add/list/delete dimensionGroups by @lavigne958 in #1010
  Add method to hide rows/columns by @lavigne958 in #1012
  Add ability to rename Spreadsheets (via a new Spreadsheet.update_title) by @jansim in #1013
  [#]# New Contributors * @jansim made their first contribution in #1013
- 5.2.0 (2022-02-27)
  Copy comments when during spreadsheet copy by @lavigne958 in #979
  Update user-guide.rst by @maky-hnou in #980
  merge setup test cassettes by @lavigne958 in #982
  Feature/add header validation get all records by @lavigne958 in #984
  Add timeout to client by @lavigne958 in #987
  Feature/update timezone and locale by @lavigne958 in #989
  Feature/make case comparison in find by @lavigne958 in #990
  Updated API rate limits by @hvinayan in #993
  Feature/prevent insert row to sheet with colon by @lavigne958 in #992
  [#]# New Contributors * @maky-hnou made their first contribution in #980 * @hvinayan made their first contribution in #993
- 5.1.1 (2021-12-22)
  Fix documentation about oauth (#975 by @lavigne958)
- 5.1.0 (2021-12-22)
  Codespell skip docs build folder (#962 by @lavigne958)
  Update contributing guidelines (#964 by @lavigne958)
  Add oauth from dict (#967 by @lavigne958)
  Update README.md to include badges (#970 by @lavigne958)
  Add new method to get all values as a list of Cells (#968 by @lavigne958)
  automatic conversion of a cell letter to uppercase (#972 by @Burovytskyi)
- 5.0.0 (2021-11-26)
  Fix a typo in HISTORY.rst (#904 by @TurnrDev)
  Fix typo and fix return value written in docstrings (#903 by @rariyama)
  Add deprecation warning for delete_row method in documentation (#909 by @javad94)
  split files models.py and test.py (#912 by @lavigne958)
  parent 39d1ecb59ca3149a8f46094c720efab883a0dc11 author Christian Clauss <cclauss@me.com> 1621149013 +0200 commit
  ter Christian Clauss <cclauss@me.com> 1630103641 +0200 (#869 by @cclaus)
  Enable code linter in CI (#915 by @lavigne958)
  isort your imports (again), so you don't have to (#914 by @cclaus)
  lint_python.yml: Try 'tox -e py' to test current Python (#916 by @cclaus)
  Add more flake8 tests (#917 by @cclaus)
  Update test suite (#918 by @cclaus)
  Avoid IndexError when row_values() returns an empty row (#920 by @cclaus)
  Bugfix - remove wrong argument in batch_update docstring (#912 by @lavigne958)
  Improvement - Add Worksheet.index property (#922 by @lavigne958)
  Add ability to create directory if it does not exist before saving the credentials to disk. (#925 by @benhoman)
  Update test framework and VCR and cassettes (#926 by @lavigne958)
  Delete .travis.yml (#928 by @cclaus)
  Update tox.ini with all linting commands under lint env (by @lavigne958)
  Build package and docs in CI (#930 by @lavigne958)
  Update oauth2.rst (#933 by @amlestin)
  Update the link to the Google Developers Console (#934 by @Croebh)
  allow tests to run on windows, add and improve tests in WorksheetTests, add test on unbounded range, use canonical range as specified in the API,
  add test cassettes, prevent InvalidGridRange, improve code formatting (#937 by @Fendse)
  fix fully qualified class names in API documentation (#944 by @geoffbeier)
  fix editor_users_emails - get only from list not all users added to spreadsheet (#939 by @Lukasz)
  add shadow method to get a named range from a speadsheet instance (#941 by @lavigne958)
  auto_resize_columns (#948 by @FelipeSantos75)
  add functions for defining, deleting and listing named ranges (#945 by @p-doyle)
  Implement open sheet within Drive folder (#951 by @datavaluepeople)
  Fix get range for unbounded ranges (#954 by @lavigne958)
  remove potential I/O when reading spreadsheet title (956 by @lavigne958)
  Add include_values_in_response to append_row & append_rows (#957 by @martimarkov)
  replace raw string "ROWS" & "COLUMNS" to Dimension named tuple, replace raw string "FORMATTED_VALUE", "UNFORMATTED_VALUE", "FORMULA"
  to ValueRenderOption named tuple, replace raw string "RAW", "USER_ENTERED" to ValueInputOption named tuple (#958 by @ccppoo)
-  4.0.1 (2021-08-07)
  Do not overwrite original value when trying to convert to a number (#902 by @lavigne958)
- 4.0.0 (2021-08-01)
  Changed Worksheet.find() method returns None if nothing is found (#899 by @GastonBC)
  Add Worksheet.batch_clear() to clear multiple ranges. (#897 by @lavigne958)
  Fix copy_permission argument comparison in Client.copy() method (#898 by @lavigne958)
  Allow creation of spreadhsheets in a shared drive (#895 by @lavigne958)
  Allow gspread.oauth() to accept a custom credential file (#891 by @slmtpz)
  Update tox.ini, remove python2 from env list (#887 by @cclaus)
  Add SpreadSheet.get_worksheet_by_id() method (#857 by @a-crovetto)
  Fix store_credentials() when authorized_user_filename is passed (#884 by @neuenmuller)
  Remove python2 (#879 by @lavigne958)
  Use Makefile to run tests (#883 by @lavigne958)
  Update documentation Authentication:For End Users using OAuth Client ID (#835 by @ManuNaEira)
  Allow fetching named ranges from Worksheet.range() (#809 by @agatti)
  Update README to only mention python3.3+ (#877 by @lavigne958)
  Fetch creation and lastUpdate time from SpreadSheet on open (#872 by @lavigne958)
  Fix bug with Worksheet.insert_row() with value_input_option argument (#873 by @elijabesu)
  Fix typos in doc and comments (#868 by @cclauss)
  Auto cast numeric values from sheet cells to python int or float (#866 by @lavigne958)
  Add Worksheet.get_values() method (#775 by @burnash)
  Allow gspread.oauth() to accept a custom filename (#847 by @bastienboutonnet)
  Document dictionary credentials auth (#860 by @dmytrostriletskyi)
  Add Worksheet.get_note() (#855 by @water-ghosts )
  Add steps for creating new keys (#856 by @hanzala-sohrab)
  Add folder_id argument to Client.copy() (#851 by @punnerud)
  Fix typos in docstrings (#848 by @dgilman)
* Fri Mar 19 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.7.0:
  * Add `Worksheet.insert_note()`, `Worksheet.update_note()`, `Worksheet.clear_note()` (#818 by @lavigne958)
  * Add `Worksheet.insert_cols()` (#802 by @AlexeyDmitriev)
  * Add `value_render_option` parameter to `Worksheet.get_all_records()` (#776 by @damgad)
  * Remove `requests` from `install_requires` (#801)
  * Simplify implementation of `Worksheet.insert_rows()` (#799 by @AlexeyDmitriev)
  * Add `auth.service_account_from_dict()` (#785 b7 @mahenzon)
  * Fix `ValueRange.from_json()` (#791 by @erakli)
  * Allow `auth` to be `None`. Fix #773 (#774 by @lepture)
  * Add `Worksheet.insert_rows()` (#734 by @tr-fi)
  * Add `Worksheet.copy_to()` (#758 by @JoachimKoenigslieb)
  * Add ability to create a cell instance using A1 notation (#765 by @tivaliy)
  * Add `auth.service_account()` (#768)
  * Add Authlib usage (#552 by @lepture)
  * Simplified OAuth2 flow (#762)
  * Fix `Worksheet.delete_rows()` index error (#760 by @rafa-guillermo)
  * Deprecate `Worksheet.delete_row()` (#766)
  * Scope `Worksheet.find()` to a specific row or a column (#739 by @alfonsocv12)
  * Add `Worksheet.add_protected_range()` #447 (#720 by @KesterChan01)
  * Add ability to fetch cell address in A1 notation (#763 by @tivaliy)
  * Add `Worksheet.delete_columns()` (#761 by @rafa-guillermo)
  * Ignore numericising specific columns in `get_all_records` (#701 by @benjamindhimes)
  * Add option ``folder_id`` when creating a spreadsheet (#754 by @Abdellam1994)
  * Add `insertDataOption` to `Worksheet.append_row()` and `Worksheet.append_rows()` (#719 by @lobatt)
  * Fix `TypeError` when using gspread in google colab (#750)
  * Remove `oauth2client` in favor of `google-auth` #472, #529 (#637 by @BigHeadGeorge)
  * Convert `oauth2client` credentials to `google-auth` (#711 by @aiguofer)
  * Remove unnecessary `login()` from `gspread.authorize`
  * Fix sheet name quoting issue (#554, #636, #716):
    + Add quotes to worksheet title for get_all_values (#640 by @grlbrwrg, #717 by @zynaxsoft)
    + Escaping title containing single quotes with double quotes (#730 by @vijay-shanker)
    + Use `utils.absolute_range_name()` to handle range names (#748)
  * Fix `numericise()`: add underscores test to work in python2 and <python3.6 (#622 by @epicfaace)
  * Add `supportsAllDrives` to Drive API requests (#709 by @justinr1234)
  * Add `Worksheet.merge_cells()` (#713 by @lavigne958)
  * Improve `Worksheet.merge_cells()` and add `merge_type` parameter (#742 by @aiguofer)
  * Add `Worksheet.sort()` (#639 by @kirillgashkov)
  * Add ability to reorder worksheets #570 (#571 by @robin900)
    + Add `Spreadsheet.reorder_worksheets()`
    + Add `Worksheet.update_index()`
  * Add `test_update_cell_objects` (#698 by @ogroleg)
  * Add `Worksheet.append_rows()` (#556 by @martinwarby, #694 by @fabytm)
  * Add `Worksheet.delete_rows()` (#615 by @deverlex)
  * Speed up `Client.open()` by querying files by title in Google Drive (#684 by @aiguofer)
  * Add `freeze`, `set_basic_filter` and `clear_basic_filter` methods to `Worksheet` (#574 by @aiguofer)
  * Use Drive API v3 for creating and deleting spreadsheets (#573 by @aiguofer)
  * Implement `value_render_option` in `get_all_values` (#648 by @mklaber)
  * Set position of a newly added worksheet (#688 by @djmgit)
  * Add url properties for `Spreadsheet` and `Worksheet` (#725 by @CrossNox)
* Wed Apr  8 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.3.1
  * Support old and new collections.abc.Sequence  (#745 by @timgates42)
  * Added `Spreadsheet.values_batch_update()` (#731)
  * Added more parameters to `Worksheet.append_row()` (#726)
  * Fix usage of client.openall when a title is passed in (#572 by @aiguofer)
  * Fixed sharing from Team Drives (#646 by @wooddar)
  * Fixed KeyError in list comprehension in `Spreadsheet.remove_permissions()` (#643 by @wooddar)
  * Added `Spreadsheet.values_batch_get()` (#705 by @aiguofer)
  * Added `stacklevel=2` to deprecation warnings
* Tue Mar 31 2020 Paolo Stivanin <info@paolostivanin.com>
- remove nose dep since we are not running tests
* Fri Mar 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.1.0:
  * Dropped Python 2.6 support
  * Fixed KeyError in urllib.quote in Python 2 (#605, #558)
  * Fixed Worksheet.title being out of sync after using update_title (#542 by @ryanpineo)
  * Fix parameter typos in docs (#616 by @bryanallen22)
  * Miscellaneous docs fixes (#604 by @dgilman)
  * Fixed typo in docs (#591 by @davidefiocco)
  * Added a method to copy spreadsheets (#625 by @dsask)
  * Added with_link attribute when sharing / adding permissions (#621 by @epicfaace)
  * Added ability to duplicate a worksheet (#617)
  * Change default behaviour of numericise function #499 (#502 by @danthelion)
  * Added stacklevel=2 to deprecation warnings
- Switch to github tarball for tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Jul 26 2018 jengelh@inai.de
- Trim bias from description.
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 3.0.0
  * This version drops Google Sheets API v3 support.
    > API v4 was the default backend since version 2.0.0.
    > All v4-related code has been moved from `gspread.v4` module to `gspread` module.
- Update to 2.1.1
  * Fixed #533 (#534 by @reallistic)
- Update to 2.1.0
  * URL encode the range in the value_* functions (#530 by @aiguofer)
  * Open team drive sheets by name (#527 by @ryantuck)
- Update to 2.0.1
  * Fixed #518
  * Include v4 in setup.py
  * Fetch all spreadsheets in Spreadsheet.list_spreadsheet_files (#522 by @aiguofer)
- Update to 2.0.0
  * Ported the library to Google Sheets API v4.
    This is a transition release. The v3-related code is untouched,
    but v4 is used by default. It is encouraged to move to v4 since
    the API is faster and has more features.
    API v4 is a significant change from v3. Some methods are not
    backward compatible, so there's no support for this compatibility
    in gspread either.
    These methods and properties are not supported in v4:
    > `Spreadsheet.updated`
    > `Worksheet.updated`
    > `Worksheet.export()`
    > `Cell.input_value`
- Spec file cleanups
* Fri Sep  1 2017 alarrosa@suse.com
- Fixed Source url
* Fri Aug 18 2017 alarrosa@suse.com
- Update to python-gspread 0.6.2
  * See https://github.com/burnash/gspread/blob/master/HISTORY.rst
- Use singlespec macros
* Thu Sep  4 2014 toddrme2178@gmail.com
- Initial version
